@@ -1,7 +1,7 @@
 #
 # This file is part of Reindeer
 #
-# This software is Copyright (c) 2011 by Chris Weyl.
+# This software is Copyright (c) 2017, 2015, 2014, 2012, 2011 by Chris Weyl.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package Reindeer::Builder;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-$Reindeer::Builder::VERSION = '0.018';
+$Reindeer::Builder::VERSION = '0.019';
 # ABSTRACT: Easily build a new 'Reindeer' style class
 
 use strict;
@@ -79,9 +79,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl metaclass
-
-=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
+=for :stopwords Chris Weyl Alex Balhatchet metaclass
 
 =head1 NAME
 
@@ -89,7 +87,7 @@ Reindeer::Builder - Easily build a new 'Reindeer' style class
 
 =head1 VERSION
 
-This document describes version 0.018 of Reindeer::Builder - released March 28, 2015 as part of Reindeer.
+This document describes version 0.019 of Reindeer::Builder - released June 09, 2017 as part of Reindeer.
 
 =head1 SYNOPSIS
 
@@ -166,15 +164,10 @@ L<L<Reindeer>, L<Moose::Exporter>.|L<Reindeer>, L<Moose::Exporter>.>
 
 =back
 
-=head1 SOURCE
-
-The development version is on github at L<http://https://github.com/RsrchBoy/reindeer>
-and may be cloned from L<git://https://github.com/RsrchBoy/reindeer.git>
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/reindeer/issues
+L<https://github.com/RsrchBoy/reindeer/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -184,28 +177,9 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
-=head2 I'm a material boy in a material world
-
-=begin html
-
-<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
-<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
-<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Freindeer&title=RsrchBoy's%20CPAN%20Reindeer&tags=%22RsrchBoy's%20Reindeer%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
-
-=end html
-
-Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
-rather B<it is simply a very pleasant surprise>. I largely create and release
-works like this because I need them or I find it enjoyable; however, don't let
-that stop you if you feel like it ;)
-
-L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Freindeer&title=RsrchBoy's%20CPAN%20Reindeer&tags=%22RsrchBoy's%20Reindeer%20in%20the%20CPAN%22>,
-L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Chris Weyl.
+This software is Copyright (c) 2017, 2015, 2014, 2012, 2011 by Chris Weyl.
 
 This is free software, licensed under:
 
